@@ -4,11 +4,14 @@
 
 use v5.14;
 
+use strict;
+use warnings;
+
 use lib 'lib', '../lib';
 
 my $domain = $ARGV[0] || 'example.com';
 
-use if $ENV{PERL_ANYEVENT_DNS} eq 'EtcHosts' || ! $ENV{PERL_ANYEVENT_DNS}, 'AnyEvent::DNS::EtcHosts';
+use if ($ENV{PERL_ANYEVENT_DNS} || "") eq 'EtcHosts' || !$ENV{PERL_ANYEVENT_DNS}, 'AnyEvent::DNS::EtcHosts';
 use AnyEvent::DNS;
 
 my $cv = AE::cv;
